Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(613)

Unified Diff: vboot_firmware/include/load_firmware_fw.h

Issue 2745007: Major refactoring of structures, with unit tests. (Closed) Base URL: ssh://gitrw.chromium.org/vboot_reference.git
Patch Set: Implemented LoadFirmware2() Created 10 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: vboot_firmware/include/load_firmware_fw.h
diff --git a/vboot_firmware/include/load_firmware_fw.h b/vboot_firmware/include/load_firmware_fw.h
index 58dd6da55fe1bccdaa31226c2f8349f27efdbc42..312a0aaa6c7290e76849533efcca342df83a07c3 100644
--- a/vboot_firmware/include/load_firmware_fw.h
+++ b/vboot_firmware/include/load_firmware_fw.h
@@ -44,8 +44,10 @@ void UpdateFirmwareBodyHash(uint8_t* data, uint64_t size);
typedef struct LoadFirmwareParams {
/* Inputs to LoadFirmware() */
void *firmware_root_key_blob; /* Key used to sign firmware header */
- void *verification_block_0; /* Key block + preamble for firmware 0 */
- void *verification_block_1; /* Key block + preamble for firmware 1 */
+ void *verification_block_0; /* Key block + preamble for firmware 0 */
+ void *verification_block_1; /* Key block + preamble for firmware 1 */
+ uint64_t verification_size_0; /* Verification block 0 size in bytes */
+ uint64_t verification_size_1; /* Verification block 1 size in bytes */
/* Outputs from LoadFirmware(); valid only if LoadFirmware() returns
* LOAD_FIRMWARE_SUCCESS. */

Powered by Google App Engine
This is Rietveld 408576698